#
# spec file for package clazy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clazy
Version:        1.11git.20230920T205027~2965bc3
Release:        1.6
Summary:        Qt oriented code checker based on the Clang framework
License:        LGPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://www.kdab.com/clazy-video/
Source0:        https://download.kde.org/stable/%{name}/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  clang
BuildRequires:  clang-devel >= 8.0
BuildRequires:  cmake >= 3.7
BuildRequires:  libstdc++-devel
%requires_eq    clang%{_llvm_sonum}

%description
clazy is a compiler plugin which allows Clang to understand Qt semantics.
You get more than 50 Qt related compiler warnings, ranging from unneeded memory
allocations to misusage of API, including fix-its for automatic refactoring.

%prep
%autosetup -p1

%build
%define _lto_cflags %{nil}

%cmake

%cmake_build

%install
%cmake_install

sed -i 's#%{_bindir}/env sh$#/bin/sh#' %{buildroot}%{_bindir}/clazy

%files
%license COPYING-LGPL2.txt
%doc %{_datadir}/doc/clazy
%doc README.md HOWTO Changelog
%{_bindir}/clazy
%{_bindir}/clazy-standalone
%{_datadir}/metainfo/org.kde.clazy.metainfo.xml
%{_libdir}/ClazyPlugin.so
%{_mandir}/man1/clazy.1%{?ext_man}

%changelog
* Fri Sep 29 2023 christophe@krop.fr
- Update to version 1.11git.20230920T205027~2965bc3:
  * add missing PrintSupport module for no-module-include check (kde#474657)
  * Allow `clazy --list` to print the new no-module-include check
  * Add new no-module-include check in checks.json (kde#474706)
  * add new no-module-include check
  * Add sanitize-inline-keyword check
  * clazy-standalone: improve --ignore-included-files help message
  * Fix compilation with LLVM 17.0.0 (rc2)
- Drop patch, now upstream:
  * 0001-Limit-the-clang-AST-crash-workaround-to-clang-7.0.patch
  * 0001-Fix-crash-when-Q_PROPERTY-contents-is-empty.patch
  * 0001-Allow-passing-no-check-in-plugin-arg-clazy-commandli.patch
  * 0001-Build-fixes-for-LLVM-Clang-15.0.0.patch
  * 0001-Adapt-to-API-changes-in-clang-llvm-16.patch
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Add upstream change to fix build with clang 16:
  * 0001-Adapt-to-API-changes-in-clang-llvm-16.patch
* Tue Sep 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream changes:
  * 0001-Limit-the-clang-AST-crash-workaround-to-clang-7.0.patch
  * 0001-Fix-crash-when-Q_PROPERTY-contents-is-empty.patch
  * 0001-Allow-passing-no-check-in-plugin-arg-clazy-commandli.patch
  * 0001-Build-fixes-for-LLVM-Clang-15.0.0.patch
* Wed Jan 26 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.11
  * New Checks:
  - use-arrow-operator-instead-of-data
  - use-static-qregularexpression
  - unexpected-flag-enumerator-value
  - Removed inefficient-qlist check (Fixed in Qt6)
* Fri Jul 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.10
  * Requires C++17
  * Fixed a -Wclazy-lambda-in-connect false-positive
  * Fixed crash in copyable-polymorphic when PCH was enabled
- Drop 0001-Fix-build-with-Clang-12.patch. Fixed upstream.
* Wed Apr 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Make sure C++17 support is available for Leap builds.
* Mon Apr 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream change:
  * 0001-Fix-build-with-Clang-12.patch
* Tue Jan 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Use a stricter llvm requirement. Only relying on the llvm
  soversion is still not enough. (kde#432078)
* Mon Jan 11 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.9:
  * Fixed clazy slowdown introduced in 1.8. It can be up to 4x
    faster now.
* Wed Nov 25 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.8:
  * New Checks:
  - qt6-qhash-signature
  - qt6-header-fixes
  - qt6-deprecated-api-fixes
  - use-chrono-in-qtimer
  - fixit for missing-qobject-macro
- Drop patches merged upstream:
  * 0001-updated-for-compatibility-with-LLVM-10.patch
  * 0001-updated-for-compatibility-with-LLVM-10-clazy-standal.patch
* Thu Nov 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Make sure the clang executables matching the libraries we link
  to are installed (mitigates boo#1178637).
* Mon Oct 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patches to address build issues with LLVM11:
  * 0001-updated-for-compatibility-with-LLVM-10.patch
  * 0001-updated-for-compatibility-with-LLVM-10-clazy-standal.patch
* Tue Jun 30 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.7:
  * New Checks:
  - overloaded signal
  - invalid JNI signatures
  - qstring-comparison-to-implicit-char
  - qt6-qlatin1string-to-u
  * connect-non-signal: Fix case where it didn't find the pmf
  * qstring-arg warns when using QLatin1String::arg(int), as it casts to QChar
  * Building clazy itself is 30%% faster
  * heap-allocated-small-trivial-type: less false-positives
- Drop patches merged upstream:
  * cmake-clang-cpp.patch
  * 0001-Fix-build-issues-using-llvm-10.0.0.patch
  * 0001-qstring-allocations-Fix-unit-tests-with-llvm-10.patch
* Mon May  4 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-qstring-allocations-Fix-unit-tests-with-llvm-10.patch
* Mon Mar 30 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Fix-build-issues-using-llvm-10.0.0.patch
* Wed Nov 20 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
- Use %%autosetup to simplify maintenance
* Tue Oct 15 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.6:
  * New Checks:
  - heap-allocated-small-trivial-type
  - signal-with-return-value
  - qproperty-type-mismatch, contributed by Jean-Michaël Celerier
  * Removed level3. Moved all level3 checks to manual level.
  * Fixed regressions with LLVM 9.0
  * Minimum LLVM was bumped to 5.0
  * Fixit infrastructure was overhauled
  * Clazy no longer rewrites files directly, to avoid races
    when parallel invocations change the same header.
  * Clazy now exports a yaml file with the replacements, to be
    applied with clang-apply-replacements.
  * The way to enable code rewrite is now: -Xclang -plugin-arg-clazy
  - Xclang export-fixes for clang or -export-fixes=somefile.yaml for clazy-standalone
  * All other fixit arguments and fixit env variables were removed
- Update cmake-clang-cpp.patch to make clazy build with both clang 8 and 9.
* Sat Sep 28 2019 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Add cmake-clang-cpp.patch: fix build with LLVM 9.
- Replace outdated llvm-clang-devel dependency by clang-devel.
* Tue Jul 16 2019 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto.
- Remove workarounds for older openSUSE versions.
* Fri Feb  1 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.5
  * New Checks:
    ifndef-define-typo
    lowercase-qml-type-name
    qrequiredresult-candidates
  * New Fixits:
    range-loop now supports adding missing refs or const-ref
    range-loop now supports adding qAsConst()
    function-args-by-ref now adding missing refs or const-ref (experimental)
    Introduced CLAZY_FIXIT_SUFFIX env variable
  * Removed support for the obscure -DCLAZY_BUILD_UTILS_LIB to
    simplify the CMakeLists.txt
  * Renamed the clazy plugin from ClangLazy.so to ClazyPlugin.so
  * fully-qualified-moc-types now warns for slot/invokable return
    values too. They need to be fully qualified for QML.
  * Fixed a crash (clang assert) in raw-environment-function
- BuildRequire ncurses-devel instead of pkgconfig(ncurses) on Leap
  42.3 to fix build
* Tue Sep 25 2018 Wolfgang Bauer <wbauer@tmo.at>
- Update to 1.4
  * New Checks:
    connect-by-name
    skipped-base-class
    qstring-varargs
    fully-qualified-moc-types
    qt-keywords, with fixit included
    qhash-with-char-pointer-key
    wrong-qevent-cast
    static-pmf
    raw-environment-function
    empty-qstringliteral
  * auto-unexpected-qstringbuilder now also warns for lambdas
    returning QStringBuilder
  * performance optimizations
  * Added -header-filter=<regex> option to clazy-standalone. Only
    headers matching the regexp will have warnings, besides the
    .cpp file from the translation unit, which is never filtered
    out.
  * Added -ignore-dirs=<regex> option to clazy-standalone, and its
    CLAZY_IGNORE_DIRS env variable equivalent.
  * Added CLAZY_HEADER_FILTER env variable which adds above
    functionality to both clazy and clazy-standalone
  * unused-non-trivial-variable got
    unused-non-trivial-variable-no-whitelist option
  * unused-non-trivial-variable got user-blacklist and
    user-whitelist support
  * container-inside-loop is now a manual check instead of level2
  * HiddenLevel was renamed to ManualLevel
  * connect-3arg-lambda now warns when passing a lambda to
    QTimer::singleShot() or QMenu::addAction() without a context
    object
  * old-style-connect warns for QMenu::addAction() and
    QMessageBox::open() too now
* Tue Sep  4 2018 Martin Pluskal <mpluskal@suse.com>
- Small packaging adjustements
* Wed Aug 29 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add Clazy 1.3, a code checker based on the Clang framework.
